@@ -26,10 +26,13 @@
 #include "svnfrontend/hotcopydlg_impl.h"
 #include "svnfrontend/loaddmpdlg_impl.h"
 #include "svnfrontend/stopdlg.h"
+#include "svnfrontend/leftpane/leftpane_impl.h"
+#include "svnfrontend/fronthelpers/propertylist.h"
 #include "src/settings/kdesvnsettings.h"
 #include "src/svnqt/url.hpp"
 #include "src/svnqt/repository.hpp"
 #include "src/svnqt/version_check.hpp"
+#include "src/svnqt/svnqttypes.hpp"
 
 #include <qpainter.h>
 #include <qlayout.h>
@@ -55,7 +58,7 @@
 #include <kdialog.h>
 #include <kdialogbase.h>
 
-kdesvnView::kdesvnView(KActionCollection*aCollection,QWidget *parent,const char*name)
+kdesvnView::kdesvnView(KActionCollection*aCollection,QWidget *parent,const char*name,bool full)
     : QWidget(parent,name),svn::repository::RepositoryListener(),m_Collection(aCollection),
       m_currentURL("")
 {
@@ -64,26 +67,37 @@ kdesvnView::kdesvnView(KActionCollection*aCollection,QWidget *parent,const char*
 
     m_Splitter = new QSplitter( this, "m_Splitter" );
     m_Splitter->setOrientation( QSplitter::Vertical );
+    leftpane_impl * _leftpane;
 
-#if 0
-    m_treeSplitter = new QSplitter(m_Splitter);
-    m_treeSplitter->setOrientation( QSplitter::Horizontal );
-    m_treeSplitter->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 1, m_treeSplitter->sizePolicy().hasHeightForWidth() ) );
+    if (full) {
+        m_treeSplitter = new QSplitter(m_Splitter);
+        m_treeSplitter->setOrientation( QSplitter::Horizontal );
+        m_treeSplitter->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 1, m_treeSplitter->sizePolicy().hasHeightForWidth() ) );
+
+        // just for testing - get filled with a real widget
+        _leftpane = new leftpane_impl(m_treeSplitter);
+        m_flist=new kdesvnfilelist(m_Collection,m_treeSplitter);
+    } else {
+        m_treeSplitter=0;
+        m_flist=new kdesvnfilelist(m_Collection,m_Splitter);
+        _leftpane = 0;
+    }
+
+    m_infoSplitter = new QSplitter(m_Splitter);
+    m_infoSplitter->setOrientation( QSplitter::Horizontal );
+    m_infoSplitter->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 1, m_infoSplitter->sizePolicy().hasHeightForWidth() ) );
+    m_LogWindow=new KTextBrowser(m_infoSplitter);
+    Propertylist*pl = new Propertylist(m_infoSplitter);
+    pl->setCommitchanges(true);
+    pl->addCallback(m_flist);
+    connect(m_flist,SIGNAL(sigProplist(const svn::PathPropertiesMapListPtr&,bool,const QString&)),
+            pl,SLOT(displayList(const svn::PathPropertiesMapListPtr&,bool,const QString&)));
 
-    // just for testing - get filled with a real widget
-    KListView * _listview = new KListView(m_treeSplitter);
-    _listview->addColumn("Name");
-    m_flist=new kdesvnfilelist(m_Collection,m_treeSplitter);
-#else
-    m_treeSplitter=0;
-    m_flist=new kdesvnfilelist(m_Collection,m_Splitter);
-#endif
     m_flist->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)7, (QSizePolicy::SizeType)7, 0, 1, m_flist->sizePolicy().hasHeightForWidth() ) );
-#if 0
-    m_treeSplitter->setCollapsible(m_flist,false);
-    m_Splitter->setCollapsible(m_treeSplitter,false);
-#endif
-    m_LogWindow=new KTextBrowser(m_Splitter);
+    if (full ) {
+        m_treeSplitter->setCollapsible(m_flist,false);
+        m_Splitter->setCollapsible(m_treeSplitter,false);
+    }
 
     top_layout->addWidget(m_Splitter);
     connect(m_flist,SIGNAL(sigLogMessage(const QString&)),this,SLOT(slotAppendLog(const QString&)));
@@ -94,8 +108,7 @@ kdesvnView::kdesvnView(KActionCollection*aCollection,QWidget *parent,const char*
     connect(m_flist,SIGNAL(sigUrlChanged( const QString& )),this,SLOT(slotUrlChanged(const QString&)));
     connect(this,SIGNAL(sigMakeBaseDirs()),m_flist,SLOT(slotMkBaseDirs()));
     KConfigGroup cs(Kdesvnsettings::self()->config(),"kdesvn-mainlayout");
-    QString t1;
-    t1 = cs.readEntry("split1",QString::null);
+    QString t1 = cs.readEntry("split1",QString::null);
     if (!t1.isEmpty()) {
         QTextStream st1(&t1,IO_ReadOnly);
         st1 >> *m_Splitter;
@@ -107,6 +120,13 @@ kdesvnView::kdesvnView(KActionCollection*aCollection,QWidget *parent,const char*
             st2 >> *m_treeSplitter;
         }
     }
+    if (m_infoSplitter) {
+        t1 = cs.readEntry("infosplit",QString::null);
+        if (!t1.isEmpty()) {
+            QTextStream st2(&t1,IO_ReadOnly);
+            st2 >> *m_infoSplitter;
+        }
+    }
 }
 
 void kdesvnView::slotAppendLog(const QString& text)
@@ -127,6 +147,12 @@ kdesvnView::~kdesvnView()
         st2 << *m_treeSplitter;
         cs.writeEntry("split2",t2);
     }
+    if (m_infoSplitter) {
+        t2="";
+        QTextStream st2(&t2,IO_WriteOnly);
+        st2 << *m_infoSplitter;
+        cs.writeEntry("infosplit",t2);
+    }
 }
 
 void kdesvnView::slotUrlChanged(const QString&url)
