@@ -21,6 +21,7 @@
 #include "kiosvn.h"
 #include "kiolistener.h"
 
+#include "src/svnqt/svnqttypes.hpp"
 #include "src/svnqt/dirent.hpp"
 #include "src/svnqt/url.hpp"
 #include "src/svnqt/status.hpp"
@@ -61,6 +62,9 @@
 #include <netinet/in.h>
 #include <netdb.h>
 
+namespace KIO
+{
+
 class KioSvnData
 {
 public:
@@ -128,6 +132,7 @@ svn::Revision KioSvnData::urlToRev(const KURL&url)
     return rev;
 }
 
+
 kio_svnProtocol::kio_svnProtocol(const QCString &pool_socket, const QCString &app_socket)
     : SlaveBase("kio_ksvn", pool_socket, app_socket),StreamWrittenCb()
 {
@@ -140,6 +145,8 @@ kio_svnProtocol::~kio_svnProtocol()
     delete m_pData;
 }
 
+}
+
 extern "C"
 {
     KDESVN_EXPORT int kdemain(int argc, char **argv);
@@ -160,14 +167,15 @@ int kdemain(int argc, char **argv)
         exit(-1);
     }
 
-    kio_svnProtocol slave(argv[2], argv[3]);
+    KIO::kio_svnProtocol slave(argv[2], argv[3]);
     slave.dispatchLoop();
 
     kdDebug(7101) << "*** kio_ksvn Done" << endl;
     return 0;
 }
 
-
+namespace KIO
+{
 /*!
     \fn kio_svnProtocol::listDir (const KURL&url)
  */
@@ -191,11 +199,14 @@ void kio_svnProtocol::listDir(const KURL&url)
     KIO::UDSEntry entry;
     totalSize(dlist.size());
     for (unsigned int i=0; i < dlist.size();++i) {
-        QDateTime dt = svn::DateTime(dlist[i].time());
-        if (createUDSEntry(dlist[i].name(),
-            dlist[i].lastAuthor(),
-            dlist[i].size(),
-            dlist[i].kind()==svn_node_dir?true:false,
+        if (!dlist[i] || dlist[i]->name().isEmpty()) {
+            continue;
+        }
+        QDateTime dt = svn::DateTime(dlist[i]->time());
+        if (createUDSEntry(dlist[i]->name(),
+            dlist[i]->lastAuthor(),
+            dlist[i]->size(),
+            dlist[i]->kind()==svn_node_dir?true:false,
             dt.toTime_t(),
             entry) ) {
             listEntry(entry,false);
@@ -642,17 +653,20 @@ void kio_svnProtocol::status(const KURL&wc,bool cR,bool rec)
     }
     kdDebug()<<"Status got " << dlist.count() << " entries." << endl;
     for (unsigned j=0;j<dlist.count();++j) {
+        if (!dlist[j]) {
+            continue;
+        }
         //QDataStream stream(params, IO_WriteOnly);
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"path",dlist[j].path());
-        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"text",QString::number(dlist[j].textStatus()));
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"path",dlist[j]->path());
+        setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+"text",QString::number(dlist[j]->textStatus()));
         setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "prop",
-                    QString::number(dlist[j].propStatus()));
+                    QString::number(dlist[j]->propStatus()));
         setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "reptxt",
-                    QString::number(dlist[j].reposTextStatus()));
+                    QString::number(dlist[j]->reposTextStatus()));
         setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "repprop",
-                    QString::number(dlist[j].reposPropStatus()));
+                    QString::number(dlist[j]->reposPropStatus()));
         setMetaData(QString::number(m_pData->m_Listener.counter() ).rightJustify( 10,'0' )+ "rev",
-                    QString::number(dlist[j].entry().cmtRev()));
+                    QString::number(dlist[j]->entry().cmtRev()));
         m_pData->m_Listener.incCounter();
     }
 }
@@ -688,16 +702,18 @@ void kio_svnProtocol::commit(const KURL::List&url)
     for (unsigned j=0; j<url.count();++j) {
         targets.push_back(svn::Path(url[j].path()));
     }
-    svn_revnum_t nnum=svn::Revision::UNDEFINED;
+    svn::Revision nnum=svn::Revision::UNDEFINED;
     try {
         nnum = m_pData->m_Svnclient->commit(svn::Targets(targets),msg,true,false);
     } catch (svn::ClientException e) {
         error(KIO::ERR_SLAVE_DEFINED,e.msg());
     }
     for (unsigned j=0;j<url.count();++j) {
-        QString userstring = i18n ( "Nothing to commit." );
-        if (SVN_IS_VALID_REVNUM(nnum)) {
-            userstring = i18n( "Committed revision %1." ).arg(nnum);
+        QString userstring;
+        if (nnum!=svn::Revision::UNDEFINED) {
+            userstring = i18n( "Committed revision %1." ).arg(nnum.toString());
+        } else {
+            userstring = i18n ( "Nothing to commit." );
         }
         setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "path", url[j].path() );
         setMetaData(QString::number(m_pData->m_Listener.counter()).rightJustify( 10,'0' )+ "action", "0" );
@@ -728,7 +744,7 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
 {
     svn::Revision start(revstart,revstringstart);
     svn::Revision end(revend,revstringend);
-    const svn::LogEntries * logs = 0;
+    svn::LogEntriesPtr logs;
 
     for (unsigned j = 0; j<urls.count();++j) {
         logs = 0;
@@ -769,7 +785,6 @@ void kio_svnProtocol::svnlog(int revstart,const QString&revstringstart,int reven
                 m_pData->m_Listener.incCounter();
             }
         }
-        delete logs;
     }
 }
 
@@ -921,3 +936,5 @@ QString kio_svnProtocol::getDefaultLog()
     }
     return res;
 }
+
+} // namespace KIO
