@@ -493,11 +493,11 @@ void CommandExec::slotCmd_list()
         return;
     }
     for (unsigned int i = 0; i < res.count();++i) {
-        QString d = svn::DateTime(res[i].time()).toString(QString("yyyy-MM-dd hh:mm::ss"));
+        QString d = svn::DateTime(res[i]->time()).toString(QString("yyyy-MM-dd hh:mm::ss"));
         m_pCPart->Stdout
-            << (res[i].kind()==svn_node_dir?"D":"F")<<" "
+            << (res[i]->kind()==svn_node_dir?"D":"F")<<" "
             << d << " "
-            << res[i].name()<<endl;
+            << res[i]->name()<<endl;
     }
 }
 
