@@ -29,6 +29,7 @@
 #include "keystatus.h"
 #include "opencontextmenu.h"
 #include "checkoutinfo_impl.h"
+#include "stopdlg.h"
 #include "src/settings/kdesvnsettings.h"
 #include "src/svnqt/revision.hpp"
 #include "src/svnqt/dirent.hpp"
@@ -38,6 +39,7 @@
 #include "helpers/sshagent.h"
 #include "helpers/sub2qt.h"
 #include "fronthelpers/cursorstack.h"
+#include "fronthelpers/widgetblockstack.h"
 
 #include <kapplication.h>
 #include <kiconloader.h>
@@ -100,11 +102,12 @@ public:
 
     bool intern_dropRunning;
     KURL::List intern_drops;
-    QString intern_drop_target;
+    QString intern_drop_target,merge_Src1, merge_Src2,merge_Target;
     QDropEvent::Action intern_drop_action;
     QPoint intern_drop_pos;
     QTimer drop_timer;
     QTimer dirwatch_timer;
+    QTimer propTimer;
 
     bool mousePressed;
     QPoint presspos;
@@ -137,6 +140,18 @@ public:
             m_DirWatch->startScan();
         }
     }
+    void startProptimer()
+    {
+        propTimer.start(100,true);
+    }
+    void stopProptimer()
+    {
+        propTimer.stop();
+    }
+    void connectPropTimer(QObject*ob)
+    {
+        QObject::connect(&propTimer,SIGNAL(timeout()),ob,SLOT(_propListTimeout()));
+    }
 
 private:
     void readSettings();
@@ -219,6 +234,7 @@ kdesvnfilelist::kdesvnfilelist(KActionCollection*aCollect,QWidget *parent, const
             this,SLOT(slotDropped(QDropEvent*,QListViewItem*)));
     connect(m_SvnWrapper,SIGNAL(sigGotourl(const QString&)),this,SLOT(_openURL(const QString&)));
     m_pList->connectDirTimer(this);
+    m_pList->connectPropTimer(this);
 
     setDropHighlighter(true);
     setDragEnabled(true);
@@ -238,14 +254,21 @@ void kdesvnfilelist::setupActions()
     KAction*tmp_action;
     /* local and remote actions */
     /* 1. actions on dirs AND files */
-    m_LogRangeAction = new KAction(i18n("Log..."),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_L),this,SLOT(slotMakeRangeLog()),m_filesAction,"make_svn_log");
-    m_LogFullAction = new KAction(i18n("Full Log"),"kdesvnlog",KShortcut(CTRL+Key_L),this,SLOT(slotMakeLog()),m_filesAction,"make_svn_log_full");
-    tmp_action = new KAction(i18n("Full revision tree"),"kdesvnlog",KShortcut(CTRL+Key_T),this,SLOT(slotMakeTree()),m_filesAction,"make_svn_tree");
-    tmp_action = new KAction(i18n("Partial revision tree"),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_T),
+    new KAction(i18n("Log..."),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_L),this,SLOT(slotMakeRangeLog()),m_filesAction,"make_svn_log");
+    new KAction(i18n("Full Log"),"kdesvnlog",KShortcut(CTRL+Key_L),this,SLOT(slotMakeLog()),m_filesAction,"make_svn_log_full");
+    new KAction(i18n("Full revision tree"),"kdesvnlog",KShortcut(CTRL+Key_T),this,SLOT(slotMakeTree()),m_filesAction,"make_svn_tree");
+    new KAction(i18n("Partial revision tree"),"kdesvnlog",KShortcut(SHIFT+CTRL+Key_T),
         this,SLOT(slotMakePartTree()),m_filesAction,"make_svn_partialtree");
 
-    m_propertyAction = new KAction(i18n("Properties"),"edit",
-        KShortcut(Key_P),m_SvnWrapper,SLOT(slotProperties()),m_filesAction,"make_svn_property");
+    new KAction(i18n("Properties"),"edit",
+        KShortcut(CTRL+Key_P),m_SvnWrapper,SLOT(slotProperties()),m_filesAction,"make_svn_property");
+    new KAction(i18n("Display Properties"),"edit",
+        KShortcut(Key_P),this,SLOT(slotDisplayProperties()),m_filesAction,"get_svn_property");
+
+    tmp_action = new KAction(i18n("Display last changes"),"kdesvndiff",
+                KShortcut(),this,SLOT(slotDisplayLastDiff()),m_filesAction,"make_last_change");
+    tmp_action->setToolTip(i18n("Display last changes as difference to previous commit."));
+
     m_InfoAction = new KAction(i18n("Details"),"kdesvninfo",
         KShortcut(Key_I),this,SLOT(slotInfo()),m_filesAction,"make_svn_info");
     m_RenameAction = new KAction(i18n("Move"),"move",
@@ -324,13 +347,17 @@ void kdesvnfilelist::setupActions()
     m_commitAction = new KAction(i18n("Commit"),"kdesvncommit",
         KShortcut("#"),m_SvnWrapper,SLOT(slotCommit()),m_filesAction,"make_svn_commit");
 
-    m_simpleDiffHead = new KAction(i18n("Diff local changes"),"kdesvndiff",
+    tmp_action = new KAction(i18n("Diff local changes"),"kdesvndiff",
         KShortcut(CTRL+Key_D),this,SLOT(slotSimpleBaseDiff()),m_filesAction,"make_svn_basediff");
-    m_simpleDiffHead->setToolTip(i18n("Diff working copy against BASE (last checked out version) - doesn't require access to repository"));
+    tmp_action->setToolTip(i18n("Diff working copy against BASE (last checked out version) - doesn't require access to repository"));
 
-    m_simpleDiffHead = new KAction(i18n("Diff against HEAD"),"kdesvndiff",
+    tmp_action = new KAction(i18n("Diff against HEAD"),"kdesvndiff",
         KShortcut(CTRL+Key_H),this,SLOT(slotSimpleHeadDiff()),m_filesAction,"make_svn_headdiff");
-    m_simpleDiffHead->setToolTip(i18n("Diff working copy against HEAD (last checked in version)- requires access to repository"));
+    tmp_action->setToolTip(i18n("Diff working copy against HEAD (last checked in version)- requires access to repository"));
+
+    tmp_action = new KAction(i18n("Diff items"),"kdesvndiff",
+                             KShortcut(),this,SLOT(slotDiffPathes()),m_filesAction,"make_svn_itemsdiff");
+    tmp_action->setToolTip(i18n("Diff two items"));
 
 
     m_MergeRevisionAction = new KAction(i18n("Merge two revisions"),"kdesvnmerge",
@@ -358,6 +385,12 @@ void kdesvnfilelist::setupActions()
 
     new KAction(i18n("Diff revisions"),"kdesvndiff",KShortcut(),this,SLOT(slotDiffRevisions()),m_filesAction,"make_revisions_diff");
 
+    /* folding options */
+    tmp_action = new KAction( i18n("Unfold File Tree"), 0, this , SLOT(slotUnfoldTree()), m_filesAction, "view_unfold_tree" );
+    tmp_action->setToolTip(i18n("Opens all branches of the file tree"));
+    tmp_action = new KAction( i18n("Fold File Tree"), 0, this, SLOT(slotFoldTree()), m_filesAction, "view_fold_tree" );
+    tmp_action->setToolTip(i18n("Closes all branches of the file tree"));
+
     enableActions();
     m_filesAction->setHighlightingEnabled(true);
 }
@@ -440,6 +473,7 @@ bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
     CursorStack a;
     m_SvnWrapper->killallThreads();
     clear();
+    emit sigProplist(svn::PathPropertiesMapListPtr(new svn::PathPropertiesMapList()),false,QString(""));
     m_Dirsread.clear();
     if (m_SelectedItems) {
         m_SelectedItems->clear();
@@ -478,8 +512,23 @@ bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
         setBaseUri("file://"+url.path());
     } else {
         if (url.isLocalFile()) {
-            setBaseUri(url.path());
-            if (m_SvnWrapper->isLocalWorkingCopy(url,_dummy)) {
+            QString s = url.path();
+            while(s.endsWith("/")) {
+                s.remove(s.length()-1,1);
+            }
+            QFileInfo fi(s);
+            if (fi.exists() && fi.isSymLink()) {
+                QString sl = fi.readLink();
+                if (sl.startsWith("/")) {
+                    setBaseUri(sl);
+                } else {
+                    fi.setFile(fi.dirPath()+"/"+sl);
+                    setBaseUri(fi.absFilePath());
+                }
+            } else {
+                setBaseUri(url.path());
+            }
+            if (m_SvnWrapper->isLocalWorkingCopy(baseUri(),_dummy)) {
                 setWorkingCopy(true);
             } else {
                 // yes! KURL sometimes makes a correct localfile url (file:///)
@@ -511,7 +560,6 @@ bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
     m_SvnWrapper->clearUpdateCache();
     if (isWorkingCopy()) {
         m_pList->m_DirWatch=new KDirWatch(this);
-        kdDebug()<<"Create dirwatch"<<endl;
         connect(m_pList->m_DirWatch,SIGNAL(dirty(const QString&)),this,SLOT(slotDirItemDirty(const QString&)));
         connect(m_pList->m_DirWatch,SIGNAL(created(const QString&)),this,SLOT(slotDirItemCreated(const QString&)));
         connect(m_pList->m_DirWatch,SIGNAL(deleted(const QString&)),this,SLOT(slotDirItemDeleted(const QString&)));
@@ -543,6 +591,7 @@ bool kdesvnfilelist::openURL( const KURL &url,bool noReinit )
     }
     emit changeCaption(baseUri());
     emit sigUrlOpend(result);
+    QTimer::singleShot(1,this,SLOT(readSupportData()));
     return result;
 }
 
@@ -573,7 +622,6 @@ bool kdesvnfilelist::checkDirs(const QString&_what,FileListViewItem * _parent)
     while (what.endsWith("/")) {
         what.truncate(what.length()-1);
     }
-    kdDebug()<<"checkDirs()" << endl;
     // prevent this from checking unversioned folder. FIXME: what happen when we do open url on a non-working-copy folder??
     if (!isWorkingCopy()|| (!_parent) || ((_parent) && (_parent->isVersioned()))) {
         if (!m_SvnWrapper->makeStatus(what,dlist,m_pList->m_remoteRevision) ) {
@@ -587,27 +635,31 @@ bool kdesvnfilelist::checkDirs(const QString&_what,FileListViewItem * _parent)
     svn::StatusEntries neweritems;
     m_SvnWrapper->getaddedItems(what,neweritems);
     dlist+=neweritems;
-    kdDebug() << "makeStatus on " << what << " created: " << dlist.count() << "items" <<endl;
+    bool ownupdates = true;
+    //kdDebug() << "makeStatus on " << what << " created: " << dlist.count() << "items" <<endl;
 
-    viewport()->setUpdatesEnabled(false);
+    if (isUpdatesEnabled()) {
+        viewport()->setUpdatesEnabled(false);
+    } else {
+        ownupdates=false;
+    }
     svn::StatusEntries::iterator it = dlist.begin();
     FileListViewItem * pitem = 0;
     bool main_found = false;
     for (;it!=dlist.end();++it) {
-        //kdDebug() << "iterate over it: " << (*it).entry().url() << endl;
+        //kdDebug() << "iterate over it: " << (*it)->entry().url() << endl;
 
         // current item is not versioned
-        if (!(*it).isVersioned() && !filterOut((*it))) {
-            kdDebug()<< "Found non versioned item" << endl;
+        if (!(*it)->isVersioned() && !filterOut((*it))) {
             // if empty, we may want to create a default svn::Status for each folder inside this _parent
             // iterate over QDir and create new filelistviewitem
             checkUnversionedDirs(_parent);
         }
 
-        if ((*it).path()==what||QString::compare((*it).entry().url(),what)==0){
+        if ((*it)->path()==what||QString::compare((*it)->entry().url(),what)==0){
             if (!_parent) {
                 pitem = new FileListViewItem(this,*it);
-//                kdDebug()<< "CheckDirs::creating new FileListViewitem as parent " + (*it).path() << endl;
+                //kdDebug()<< "CheckDirs::creating new FileListViewitem as parent " + (*it)->path() << endl;
                 m_Dirsread[pitem->fullName()]=true;
                 pitem->setDropEnabled(true);
             }
@@ -620,8 +672,11 @@ bool kdesvnfilelist::checkDirs(const QString&_what,FileListViewItem * _parent)
         pitem = _parent;
     }
     insertDirs(pitem,dlist);
-    viewport()->setUpdatesEnabled(true);
-    viewport()->repaint();
+    if (ownupdates) {
+        kdDebug()<<"Enable update"<<endl;
+        viewport()->setUpdatesEnabled(true);
+        viewport()->repaint();
+    }
     return true;
 }
 
@@ -632,7 +687,15 @@ void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dl
     KFileItemList oneItem;
 #endif
 
+    QTime _t;
+    _t.start();
     for (it = dlist.begin();it!=dlist.end();++it) {
+/*        if (_t.elapsed()>300) {
+           viewport()->setUpdatesEnabled(true);
+            viewport()->repaint();
+            viewport()->setUpdatesEnabled(false);
+            _t.restart();
+        }*/
         if (filterOut((*it)))
         {
             continue;
@@ -641,7 +704,7 @@ void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dl
         if (!_parent) {
             item = new FileListViewItem(this,*it);
         } else {
-            if ( (item = _parent->findChild( (*it).path() ))  ) {
+            if ( (item = _parent->findChild( (*it)->path() ))  ) {
                 delete item;
             }
             item = new FileListViewItem(this,_parent,*it);
@@ -651,7 +714,6 @@ void kdesvnfilelist::insertDirs(FileListViewItem * _parent,svn::StatusEntries&dl
             item->setDropEnabled(true);
             if (isWorkingCopy()) {
                 m_pList->m_DirWatch->addDir(item->fullName());
-                kdDebug()<< "Watching folder: " + item->fullName() << endl;
             }
         } else if (isWorkingCopy()) {
             m_pList->m_DirWatch->addFile(item->fullName());
@@ -700,7 +762,7 @@ void kdesvnfilelist::slotDirAdded(const QString&newdir,FileListViewItem*k)
         checkDirs(baseUri(),0);
         return;
     }
-    svn::Status stat;
+    svn::StatusPtr stat;
     try {
         stat = m_SvnWrapper->svnclient()->singleStatus(newdir);
     } catch (svn::ClientException e) {
@@ -757,6 +819,8 @@ void kdesvnfilelist::slotItemRead(QListViewItem*aItem)
     if (_ex &&(m_Dirsread.find(k->fullName())==m_Dirsread.end()||m_Dirsread[k->fullName()]==false)) {
         if (checkDirs(k->fullName(),k)) {
             m_Dirsread[k->fullName()]=true;
+        } else {
+            emit sigListError();
         }
     }
 }
@@ -784,18 +848,31 @@ void kdesvnfilelist::slotReinitItem(SvnItem*item)
 void kdesvnfilelist::enableActions()
 {
     bool isopen = baseUri().length()>0;
-    bool single = allSelected()->count()==1&&isopen;
-    bool multi = allSelected()->count()>1&&isopen;
-    bool none = allSelected()->count()==0&&isopen;
+    int c = allSelected()->count();
+    bool single = c==1&&isopen;
+    bool multi = c>1&&isopen;
+    bool none = c==0&&isopen;
     bool dir = false;
+    bool unique = uniqueTypeSelected();
     if (single && allSelected()->at(0)->isDir()) {
         dir = true;
     }
     KAction * temp = 0;
     /* local and remote actions */
     /* 1. actions on dirs AND files */
-    m_LogRangeAction->setEnabled(single||none);
-    m_LogFullAction->setEnabled(single||none);
+    temp = filesActions()->action("make_svn_log");
+    if (temp) {
+        temp->setEnabled(single||none);
+    }
+    temp = filesActions()->action("make_last_change");
+    if (temp) {
+        temp->setEnabled(isopen);
+    }
+
+    temp = filesActions()->action("make_svn_log_full");
+    if (temp) {
+        temp->setEnabled(single||none);
+    }
     temp = filesActions()->action("make_svn_tree");
     if (temp) {
         temp->setEnabled(single||none);
@@ -805,7 +882,14 @@ void kdesvnfilelist::enableActions()
         temp->setEnabled(single||none);
     }
 
-    m_propertyAction->setEnabled(single);
+    temp = filesActions()->action("make_svn_property");
+    if (temp) {
+        temp->setEnabled(single);
+    }
+    temp = filesActions()->action("get_svn_property");
+    if (temp) {
+        temp->setEnabled(single);
+    }
     m_DelCurrent->setEnabled( (multi||single));
     m_LockAction->setEnabled( (multi||single));
     m_UnlockAction->setEnabled( (multi||single));
@@ -819,7 +903,7 @@ void kdesvnfilelist::enableActions()
     m_BlameRangeAction->setEnabled(single&&!dir);
     m_CatAction->setEnabled(single&&!dir);
     /* 3. actions only on dirs */
-    m_MkdirAction->setEnabled(dir||!isWorkingCopy()&&isopen);
+    m_MkdirAction->setEnabled(dir||none && isopen);
     m_switchRepository->setEnabled(isWorkingCopy()&& (single||none));
     m_changeToRepository->setEnabled(isWorkingCopy());
     m_ImportDirsIntoCurrent->setEnabled(dir);
@@ -847,7 +931,7 @@ void kdesvnfilelist::enableActions()
     m_UpdateHead->setEnabled(isWorkingCopy()&&isopen);
     m_UpdateRev->setEnabled(isWorkingCopy()&&isopen);
     m_commitAction->setEnabled(isWorkingCopy()&&isopen);
-    m_simpleDiffHead->setEnabled(isWorkingCopy()&&isopen);
+
     temp = filesActions()->action("make_svn_basediff");
     if (temp) {
         temp->setEnabled(isWorkingCopy()&&(single||none));
@@ -857,6 +941,12 @@ void kdesvnfilelist::enableActions()
         temp->setEnabled(isWorkingCopy()&&(single||none));
     }
 
+    /// @todo uberprüfen ob alle selektierten items den selben typ haben.
+    temp = filesActions()->action("make_svn_itemsdiff");
+    if (temp) {
+        temp->setEnabled(multi && c==2 && unique);
+    }
+
     /* 2. on dirs only */
     m_CleanupAction->setEnabled(isWorkingCopy()&& (dir||none));
     temp = filesActions()->action("make_check_unversioned");
@@ -873,7 +963,7 @@ void kdesvnfilelist::enableActions()
 
     temp = filesActions()->action("make_revisions_diff");
     if (temp) {
-        temp->setEnabled(isopen&&single);
+        temp->setEnabled(isopen);
     }
     temp = filesActions()->action("make_revisions_cat");
     if (temp) {
@@ -895,6 +985,7 @@ void kdesvnfilelist::enableActions()
 
 void kdesvnfilelist::slotSelectionChanged()
 {
+    m_pList->stopProptimer();
     if (m_SelectedItems==0) {
         m_SelectedItems = new FileListViewItemList;
         m_SelectedItems->setAutoDelete(false);
@@ -907,6 +998,7 @@ void kdesvnfilelist::slotSelectionChanged()
         ++it;
     }
     enableActions();
+    m_pList->startProptimer();
 }
 
 /*!
@@ -1107,6 +1199,21 @@ void kdesvnfilelist::slotImportIntoDir(const KURL&importUrl,const QString&target
     delete dlg;
 }
 
+void kdesvnfilelist::readSupportData()
+{
+    QString bugurl, bugre;
+    m_SvnWrapper->setContextData("bugtraq:url",QString::null);
+    m_SvnWrapper->setContextData("bugtraq:logregex",QString::null);
+    QString p = m_SvnWrapper->searchProperty(bugurl,"bugtraq:url",baseUri(),(isWorkingCopy()?svn::Revision::WORKING:m_pList->m_remoteRevision),!isNetworked());
+    if (!p.isEmpty()) {
+        m_SvnWrapper->setContextData("bugtraq:url",bugurl);
+        p = m_SvnWrapper->searchProperty(bugre,"bugtraq:logregex",baseUri(),(isWorkingCopy()?svn::Revision::WORKING:m_pList->m_remoteRevision),!isNetworked());
+        if (!p.isEmpty()) {
+            m_SvnWrapper->setContextData("bugtraq:logregex",bugre);
+        }
+    }
+}
+
 void kdesvnfilelist::refreshCurrentTree()
 {
     QTime t;
@@ -1134,6 +1241,7 @@ void kdesvnfilelist::refreshCurrentTree()
     kdDebug()<<"Refresh time: "<<t.elapsed()<<" ms"<<endl;
     setUpdatesEnabled(true);
     viewport()->repaint();
+    QTimer::singleShot(1,this,SLOT(readSupportData()));
     //m_pList->startScan();
 }
 
@@ -1189,13 +1297,13 @@ bool kdesvnfilelist::refreshRecursive(FileListViewItem*_parent,bool down)
     bool dispchanged = false;
     for (;it!=dlist.end();++it) {
         gotit = false;
-        if ((*it).path()==what) {
+        if ((*it)->path()==what) {
             continue;
         }
         FileListViewItemListIterator clistIter(currentSync);
         while ( (k=clistIter.current()) ) {
             ++clistIter;
-            if (k->fullName()==(*it).path()) {
+            if (k->fullName()==(*it)->path()) {
                 currentSync.removeRef(k);
                 k->updateStatus(*it);
                 if (filterOut(k)) {
@@ -1558,10 +1666,21 @@ void kdesvnfilelist::slotMerge()
     FileListViewItem*which= singleSelected();
     QString src1,src2,target;
     if (isWorkingCopy()) {
-        target = which?which->fullName():baseUri();
+        if (m_pList->merge_Target.isEmpty()) {
+            target = which?which->fullName():baseUri();
+        } else {
+            target = m_pList->merge_Target;
+        }
+        src1 = m_pList->merge_Src1;
     } else {
-        src1 = which?which->fullName():baseUri();
+        if (m_pList->merge_Src1.isEmpty()){
+            src1 = which?which->fullName():baseUri();
+        } else {
+            src1 = m_pList->merge_Src1;
+        }
+        target = m_pList->merge_Target;
     }
+    src2 = m_pList->merge_Src2;
     bool force,dry,rec,irelated,useExternal;
     Rangeinput_impl::revision_range range;
     MergeDlg_impl*ptr;
@@ -1580,6 +1699,9 @@ void kdesvnfilelist::slotMerge()
             src2 = src1;
         }
         target = ptr->Dest();
+        m_pList->merge_Src2 = src2;
+        m_pList->merge_Src1 = src1;
+        m_pList->merge_Target = target;
         force = ptr->force();
         dry = ptr->dryrun();
         rec = ptr->recursive();
@@ -2022,6 +2144,76 @@ void kdesvnfilelist::slotSimpleHeadDiff()
     m_SvnWrapper->makeDiff(what,svn::Revision::WORKING,svn::Revision::HEAD,kitem?kitem->isDir():true);
 }
 
+void kdesvnfilelist::slotDisplayLastDiff()
+{
+    FileListViewItem*kitem = singleSelected();
+    QString what;
+    if (isWorkingCopy())
+    {
+        chdir(baseUri().local8Bit());
+    }
+    svn::Revision end = svn::Revision::PREV;
+    if (!kitem) {
+        if (isWorkingCopy()) {
+            QListViewItem*fi = firstChild();
+            kitem = static_cast<FileListViewItem*>(fi);
+            if (!kitem) {
+                return;
+            }
+            what = relativePath(kitem);
+        } else {
+            what=baseUri();
+        }
+    }else{
+        what = relativePath(kitem);
+    }
+    svn::Revision start;
+    svn::InfoEntry inf;
+    if (!kitem) {
+        // it has to have an item when in working copy, so we know we are in repository view.
+        if (!m_SvnWrapper->singleInfo(what,m_pList->m_remoteRevision,inf)) {
+            return;
+        }
+        start = inf.cmtRev();
+    } else {
+        start = kitem->cmtRev();
+    }
+    if (!isWorkingCopy()) {
+        if (!m_SvnWrapper->singleInfo(what,start.revnum()-1,inf)) {
+            return;
+        }
+        end = inf.cmtRev();
+    }
+    m_SvnWrapper->makeDiff(what,end,what,start,realWidget());
+}
+
+void kdesvnfilelist::slotDiffPathes()
+{
+    QPtrList<FileListViewItem>*lst = allSelected();
+
+    if (lst->count()!=2 || !uniqueTypeSelected()) {
+        return;
+    }
+    m_pList->m_fileTip->setItem(0);
+
+    FileListViewItem*k1,*k2;
+    k1 = lst->at(0);
+    k2 = lst->at(1);
+    QString w1,w2;
+    svn::Revision r1;
+
+    if (isWorkingCopy()) {
+        chdir(baseUri().local8Bit());
+        w1 = relativePath(k1);
+        w2 = relativePath(k2);
+        r1 = svn::Revision::WORKING;
+    } else {
+        w1 = k1->fullName();
+        w2 = k2->fullName();
+        r1 = m_pList->m_remoteRevision;
+    }
+    m_SvnWrapper->makeDiff(w1,r1,w2,r1);
+}
 
 /*!
     \fn kdesvnfilelist::slotMkdir()
@@ -2151,7 +2343,7 @@ bool kdesvnfilelist::refreshItem(FileListViewItem*item)
     try {
         item->setStat(svnclient()->singleStatus(item->fullName(),false,m_pList->m_remoteRevision));
     } catch (svn::ClientException e) {
-        item->setStat(svn::Status());
+        item->setStat(new svn::Status());
         return false;
     }
     return true;
@@ -2250,6 +2442,32 @@ void kdesvnfilelist::slotDirItemDirty(const QString&what)
     m_pList->startDirTimer();
 }
 
+void kdesvnfilelist::_propListTimeout()
+{
+    dispProperties(false);
+}
+
+void kdesvnfilelist::slotDisplayProperties()
+{
+    dispProperties(true);
+}
+
+void kdesvnfilelist::dispProperties(bool force)
+{
+    CursorStack a(Qt::BusyCursor);
+    bool cache_Only = (!force && isNetworked() && !Kdesvnsettings::properties_on_remote_items());
+    svn::PathPropertiesMapListPtr pm;
+    SvnItem*k = singleSelected();
+    if (!k || !k->isRealVersioned()) {
+        emit sigProplist(svn::PathPropertiesMapListPtr(),false,QString(""));
+        return;
+    }
+    kdDebug()<<"Cacheonly: "<<cache_Only<<endl;
+    svn::Revision rev(isWorkingCopy()?svn::Revision::WORKING:m_pList->m_remoteRevision);
+    pm =m_SvnWrapper->propList(k->fullName(),rev,cache_Only);
+    emit sigProplist(pm,isWorkingCopy(),k->fullName());
+}
+
 void kdesvnfilelist::_dirwatchTimeout()
 {
     kdDebug()<<"dirtimer"<<endl;
@@ -2557,7 +2775,7 @@ void kdesvnfilelist::checkUnversionedDirs( FileListViewItem * _parent )
 //
 //             svn::Status stat(fi->fileName(), &wc_stat);
 
-            svn::Status stat(fi->absFilePath());
+            svn::StatusPtr stat(new svn::Status(fi->absFilePath()));
 
             // start copying insertDirs
             FileListViewItem * item;
@@ -2602,11 +2820,12 @@ void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt,bool checkNewer,boo
     if (!_s) {
         return;
     }
-    svn::Status d;
+    svn::SharedPointer<svn::Status> d;
     while (_s) {
         //_s->makePixmap();
+
         if (!no_update) {
-            if (m_SvnWrapper->getUpdated(_s->stat().path(),d)) {
+            if (m_SvnWrapper->getUpdated(_s->stat()->path(),d) && d) {
                 _s->updateStatus(d);
             } else {
                 _s->update();
@@ -2615,7 +2834,7 @@ void kdesvnfilelist::rescanIconsRec(FileListViewItem*startAt,bool checkNewer,boo
         rescanIconsRec(_s,checkNewer,no_update);
         if (checkNewer && _s->isDir() && _s->isOpen()) {
             svn::StatusEntries target;
-            m_SvnWrapper->getaddedItems(_s->stat().path(),target);
+            m_SvnWrapper->getaddedItems(_s->stat()->path(),target);
             insertDirs(_s,target);
         }
         _s = static_cast<FileListViewItem*>(_s->nextSibling());
@@ -2770,4 +2989,87 @@ void kdesvnfilelist::slotOpenWith()
     KRun::displayOpenWithDialog(lst);
 }
 
+void kdesvnfilelist::slotUnfoldTree()
+{
+    StopSimpleDlg sdlg(0,0,i18n("Unfold tree"),i18n("Unfold all folder"));
+
+    connect(this,SIGNAL(sigListError()),
+            &sdlg,SLOT(makeCancel()));
+
+    QListViewItemIterator it(this);
+    QTime t;t.start();
+
+    setUpdatesEnabled(false);
+    {
+        WidgetBlockStack a(this);
+        while (QListViewItem* item = it.current())
+        {
+            if (item->isExpandable()) {
+                if (sdlg.isCanceld()) {
+                    m_SvnWrapper->slotCancel(true);
+                    break;
+                }
+                if (t.elapsed()>=200) {
+                    sdlg.slotTick();
+                    kapp->processEvents(20);
+                    t.restart();
+                }
+                ((FileListViewItem*)item)->setOpenNoBlock(true);
+            }
+            ++it;
+        }
+    }
+    setFocus();
+    setUpdatesEnabled(true);
+    viewport()->repaint();
+    repaint();
+    m_SvnWrapper->slotCancel(false);
+}
+
+void kdesvnfilelist::slotFoldTree()
+{
+    QListViewItemIterator it(this);
+    while (QListViewItem* item = it.current())
+    {
+        // don't close the top level directory
+        if (item->isExpandable() && item->parent())
+            item->setOpen(false);
+
+        ++it;
+    }
+}
+
+/*!
+    \fn kdesvnfilelist::uniqueSelected()
+ */
+bool kdesvnfilelist::uniqueTypeSelected()
+{
+    FileListViewItemList*ls = allSelected();
+    FileListViewItemListIterator it(*ls);
+    FileListViewItem*cur=it.current();
+    if (!cur) {
+        return false;
+    }
+    bool dir = cur->isDir();
+    while ( (cur=it.current())!=0) {
+        ++it;
+        if (cur->isDir()!=dir) {
+            return false;
+        }
+    }
+    return true;
+}
+
+void kdesvnfilelist::slotChangeProperties(const svn::PropertiesMap&pm,const QValueList<QString>&dellist,const QString&path)
+{
+    m_SvnWrapper->changeProperties(pm,dellist,path);
+    FileListViewItem* which = singleSelected();
+    kdDebug()<<(which?which->fullName():"nix") << " -> " << path<<endl;
+    if (which && which->fullName()==path) {
+        which->refreshStatus();
+        refreshCurrent(which);
+        _propListTimeout();
+    }
+}
+
 #include "kdesvnfilelist.moc"
