@@ -76,8 +76,8 @@ protected:
     QMap<QString,bool> m_Dirsread;
 
     KActionCollection* m_filesAction;
-    KAction*m_LogFullAction,*m_LogRangeAction,*m_BlameAction,*m_BlameRangeAction,*m_CatAction,*m_MkdirAction;
-    KAction*m_InfoAction,*m_propertyAction,*m_commitAction,*m_simpleDiffHead,*m_UpdateHead,*m_UpdateRev;
+    KAction*m_BlameAction,*m_BlameRangeAction,*m_CatAction,*m_MkdirAction;
+    KAction*m_InfoAction,*m_commitAction,*m_UpdateHead,*m_UpdateRev;
     KAction*m_AddCurrent,*m_DelCurrent,*m_CheckoutAction,*m_CheckoutCurrentAction,*m_RevertAction;
     KAction*m_changeToRepository,*m_switchRepository,*m_ExportAction,*m_ExportCurrentAction;
     KAction*m_CleanupAction,*m_ResolvedAction,*m_ImportDirsIntoCurrent,*m_RefreshViewAction,*m_MergeRevisionAction;
@@ -167,12 +167,17 @@ protected slots:
     virtual void slotCopy();
     virtual void slotCat();
     virtual void slotDelete();
+    virtual void slotDisplayLastDiff();
 
     /* callback slots */
     virtual void slotCopyFinished( KIO::Job *);
     virtual void slotDeleteFinished(KIO::Job*);
     virtual void _openURL(const QString&);
     virtual void _dirwatchTimeout();
+    virtual void _propListTimeout();
+
+    /* internal slots */
+    virtual void readSupportData();
 
 signals:
     void sigLogMessage(const QString&);
@@ -181,6 +186,8 @@ signals:
     void sigUrlOpend(bool);
     void sigSwitchUrl(const KURL&);
     void sigUrlChanged(const QString&);
+    void sigProplist(const svn::PathPropertiesMapListPtr&,bool,const QString&);
+    void sigListError();
 
 public slots:
     virtual void refreshCurrentTree();
@@ -189,6 +196,8 @@ public slots:
     virtual void slotMkdir();
     virtual void slotMkBaseDirs();
     virtual void slotSettingsChanged();
+    virtual void slotChangeProperties(const svn::PropertiesMap&,const QValueList<QString>&,const QString&);
+
 
 protected slots:
     virtual void slotLock();
@@ -200,6 +209,7 @@ protected slots:
     virtual void slotSimpleBaseDiff();
 
     virtual void slotDiffRevisions();
+    virtual void slotDiffPathes();
     virtual void slotRevisionCat();
     virtual void slotCheckUpdates();
     virtual void slotInfo();
@@ -215,10 +225,17 @@ protected slots:
     virtual void slotMakePartTree();
     virtual void slotInternalDrop();
     virtual void slotOpenWith();
+    virtual void slotDisplayProperties();
+
+	virtual void slotUnfoldTree();
+	virtual void slotFoldTree();
 
 private slots:
     void gotPreview( const KFileItem*, const QPixmap& );
     void gotPreviewResult();
+protected:
+    virtual bool uniqueTypeSelected();
+    virtual void dispProperties(bool);
 };
 
 #endif
