@@ -22,8 +22,8 @@
 #include "svnactions.h"
 #include "kdesvn_part.h"
 #include "src/settings/kdesvnsettings.h"
-#include "svnqt/status.hpp"
-#include "svnqt/smart_pointer.hpp"
+#include "src/svnqt/status.hpp"
+#include "src/svnqt/smart_pointer.hpp"
 #include "helpers/sub2qt.h"
 #include "helpers/ktranslateurl.h"
 
@@ -47,14 +47,14 @@ class SvnItem_p:public svn::ref_count
     friend class SvnItem;
 public:
     SvnItem_p();
-    SvnItem_p(const svn::Status&);
+    SvnItem_p(const svn::StatusPtr&);
     virtual ~SvnItem_p();
     KFileItem*createItem(const svn::Revision&peg);
     const KURL& kdeName(const svn::Revision&);
     KMimeType::Ptr mimeType(bool dir=false);
 
 protected:
-    svn::Status m_Stat;
+    svn::StatusPtr m_Stat;
     void init();
     QString m_url,m_full,m_short;
     KURL m_kdename;
@@ -67,12 +67,12 @@ protected:
 };
 
 SvnItem_p::SvnItem_p()
-    :ref_count(),m_Stat()
+    :ref_count(),m_Stat(new svn::Status())
 {
     init();
 }
 
-SvnItem_p::SvnItem_p(const svn::Status&aStat)
+SvnItem_p::SvnItem_p(const svn::StatusPtr&aStat)
     :ref_count(),m_Stat(aStat)
 {
     init();
@@ -85,7 +85,7 @@ SvnItem_p::~SvnItem_p()
 
 void SvnItem_p::init()
 {
-    m_full = m_Stat.path();
+    m_full = m_Stat->path();
     m_kdename="";
     mptr = 0;
     lRev=svn::Revision::UNDEFINED;
@@ -100,8 +100,8 @@ void SvnItem_p::init()
     } else {
         m_short = m_full;
     }
-    m_url = m_Stat.entry().url();
-    m_fullDate = svn::DateTime(m_Stat.entry().cmtDate());
+    m_url = m_Stat->entry().url();
+    m_fullDate = svn::DateTime(m_Stat->entry().cmtDate());
     m_infoText = QString::null;
     m_fitem = 0;
 }
@@ -123,12 +123,12 @@ KMimeType::Ptr SvnItem_p::mimeType(bool dir)
 
 const KURL& SvnItem_p::kdeName(const svn::Revision&r)
 {
-    isWc = QString::compare(m_Stat.entry().url(),m_Stat.path())!=0;
+    isWc = QString::compare(m_Stat->entry().url(),m_Stat->path())!=0;
     QString name;
     if (!(r==lRev)||m_kdename.isEmpty()) {
         lRev=r;
         if (!isWc) {
-            m_kdename = m_Stat.entry().url();
+            m_kdename = m_Stat->entry().url();
             QString proto;
             proto = helpers::KTranslateUrl::makeKdeUrl(m_kdename.protocol());
             m_kdename.setProtocol(proto);
@@ -137,7 +137,7 @@ const KURL& SvnItem_p::kdeName(const svn::Revision&r)
                 m_kdename.setQuery("?rev="+revstr);
             }
         } else {
-            m_kdename = KURL::fromPathOrURL(m_Stat.path());
+            m_kdename = KURL::fromPathOrURL(m_Stat->path());
         }
     }
     return m_kdename;
@@ -159,7 +159,7 @@ SvnItem::SvnItem()
     m_overlaycolor = false;
 }
 
-SvnItem::SvnItem(const svn::Status&aStat)
+SvnItem::SvnItem(const svn::StatusPtr&aStat)
     : p_Item(new SvnItem_p(aStat))
 {
     m_overlaycolor = false;
@@ -169,7 +169,7 @@ SvnItem::~SvnItem()
 {
 }
 
-void SvnItem::setStat(const svn::Status&aStat)
+void SvnItem::setStat(const svn::StatusPtr&aStat)
 {
     m_overlaycolor = false;
     p_Item = new SvnItem_p(aStat);
@@ -192,8 +192,8 @@ const QString&SvnItem::Url()const
 
 bool SvnItem::isDir()const
 {
-    if (isRemoteAdded() || p_Item->m_Stat.entry().isValid()) {
-        return p_Item->m_Stat.entry().kind()==svn_node_dir;
+    if (isRemoteAdded() || p_Item->m_Stat->entry().isValid()) {
+        return p_Item->m_Stat->entry().kind()==svn_node_dir;
     }
     /* must be a local file */
     QFileInfo f(fullName());
@@ -231,72 +231,70 @@ QPixmap SvnItem::internalTransform(const QPixmap&first,int size)
 
 QPixmap SvnItem::getPixmap(const QPixmap&_p,int size,bool overlay)
 {
-    QPixmap p;
-    if (_p.width()!=size || _p.height()!=size) {
-         p = internalTransform(_p,size);
-    } else {
-        p = _p;
-    }
-
-//    if (QString::compare(p_Item->m_Stat.entry().url(),p_Item->m_Stat.path())!=0) {
-        if (!isVersioned()) {
-            m_bgColor = NOTVERSIONED;
-        } else if (isRealVersioned()) {
-            SvnActions*wrap = getWrapper();
-            bool mod = false;
-            QPixmap p2 = QPixmap();
-            if (p_Item->m_Stat.textStatus ()==svn_wc_status_conflicted) {
+    if (!isVersioned()) {
+        m_bgColor = NOTVERSIONED;
+    } else if (isRealVersioned()) {
+        SvnActions*wrap = getWrapper();
+        bool mod = false;
+        QPixmap p2 = QPixmap();
+        if (p_Item->m_Stat->textStatus()==svn_wc_status_conflicted) {
+            m_bgColor = CONFLICT;
+            if (overlay)
+                p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnconflicted",KIcon::Desktop,size);
+        } else if (p_Item->m_Stat->textStatus ()==svn_wc_status_missing) {
+            m_bgColor = MISSING;
+        } else if (isLocked()||wrap->checkReposLockCache(fullName())) {
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
+            m_bgColor = LOCKED;
+        } else if (Kdesvnsettings::check_needslock() && !isRemoteAdded() && wrap->isLockNeeded(this,svn::Revision::UNDEFINED) ) {
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnneedlock",KIcon::Desktop,size);
+            m_bgColor = NEEDLOCK;
+        } else if (wrap->isUpdated(p_Item->m_Stat->path())) {
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
+            m_bgColor = UPDATES;
+        } else if (p_Item->m_Stat->textStatus()==svn_wc_status_deleted) {
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvndeleted",KIcon::Desktop,size);
+            m_bgColor = DELETED;
+        } else if (p_Item->m_Stat->textStatus()==svn_wc_status_added ) {
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnadded",KIcon::Desktop,size);
+            m_bgColor = ADDED;
+        } else if (isModified()) {
+            mod = true;
+        } else if (isDir()&&wrap) {
+            svn::StatusEntries dlist;
+            svn::StatusEntries::const_iterator it;
+            if (isRemoteAdded() || wrap->checkUpdateCache(fullName())) {
+                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
+                m_bgColor = UPDATES;
+            } else if (wrap->checkConflictedCache(fullName())) {
                 m_bgColor = CONFLICT;
                 if (overlay)
                     p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnconflicted",KIcon::Desktop,size);
-            } else if (p_Item->m_Stat.textStatus ()==svn_wc_status_missing) {
-                m_bgColor = MISSING;
-            } else if (isLocked()||wrap->checkReposLockCache(fullName())) {
-                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
-                m_bgColor = LOCKED;
-            } else if (!isRemoteAdded() && wrap->isLockNeeded(this,svn::Revision::UNDEFINED) ) {
-                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnneedlock",KIcon::Desktop,size);
-                m_bgColor = NEEDLOCK;
-            } else if (wrap->isUpdated(p_Item->m_Stat.path())) {
-                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
-                m_bgColor = UPDATES;
-            } else if (p_Item->m_Stat.textStatus()==svn_wc_status_deleted) {
-                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvndeleted",KIcon::Desktop,size);
-                m_bgColor = DELETED;
-            } else if (p_Item->m_Stat.textStatus()==svn_wc_status_added ) {
-                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnadded",KIcon::Desktop,size);
-                m_bgColor = ADDED;
-            } else if (isModified()) {
-                mod = true;
-            } else if (isDir()&&wrap) {
-                svn::StatusEntries dlist;
-                svn::StatusEntries::const_iterator it;
-                if (isRemoteAdded() || wrap->checkUpdateCache(fullName())) {
-                    if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnupdates",KIcon::Desktop,size);
-                    m_bgColor = UPDATES;
-                } else if (wrap->checkConflictedCache(fullName())) {
-                    m_bgColor = CONFLICT;
-                    if (overlay)
-                        p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnconflicted",KIcon::Desktop,size);
-                } else {
-                    mod = wrap->checkModifiedCache(fullName());
-                }
-            }
-            if (mod) {
-                m_bgColor = MODIFIED;
-                if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnmodified",KIcon::Desktop,size);
-            }
-            if (!p2.isNull()) {
-                m_overlaycolor = true;
-                QImage i1; i1 = p;
-                QImage i2;i2 = p2;
-
-                KIconEffect::overlay(i1,i2);
-                p = i1;
+            } else {
+                mod = wrap->checkModifiedCache(fullName());
             }
         }
-//    }
-    return p;
+        if (mod) {
+            m_bgColor = MODIFIED;
+            if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnmodified",KIcon::Desktop,size);
+        }
+        if (!p2.isNull()) {
+            QPixmap p;
+            if (_p.width()!=size || _p.height()!=size) {
+                p = internalTransform(_p,size);
+            } else {
+                p = _p;
+            }
+            m_overlaycolor = true;
+            QImage i1; i1 = p;
+            QImage i2;i2 = p2;
+
+            KIconEffect::overlay(i1,i2);
+            p = i1;
+            return p;
+        }
+    }
+    return _p;
 }
 
 QPixmap SvnItem::getPixmap(int size,bool overlay)
@@ -307,7 +305,7 @@ QPixmap SvnItem::getPixmap(int size,bool overlay)
     /* yes - different way to "isDir" above 'cause here we try to use the
        mime-features of KDE on ALL not just unversioned entries.
      */
-    if (QString::compare(p_Item->m_Stat.entry().url(),p_Item->m_Stat.path())==0) {
+    if (QString::compare(p_Item->m_Stat->entry().url(),p_Item->m_Stat->path())==0) {
         /* remote access */
         p = p_Item->mimeType(isDir())->pixmap(KIcon::Desktop,size,KIcon::DefaultState);
         if (isLocked()) {
@@ -315,10 +313,10 @@ QPixmap SvnItem::getPixmap(int size,bool overlay)
             QPixmap p2;
             if (overlay) p2 = kdesvnPartFactory::instance()->iconLoader()->loadIcon("kdesvnlocked",KIcon::Desktop,size);
             if (!p2.isNull()) {
-            	QImage i1; i1 = p;
-            	QImage i2; i2 = p2;
-            	KIconEffect::overlay(i1,i2);
-            	p = i1;
+                QImage i1; i1 = p;
+                QImage i2; i2 = p2;
+                KIconEffect::overlay(i1,i2);
+                p = i1;
             }
         }
     } else {
@@ -340,7 +338,7 @@ QPixmap SvnItem::getPixmap(int size,bool overlay)
 
 bool SvnItem::isVersioned()const
 {
-    return p_Item->m_Stat.isVersioned();
+    return p_Item->m_Stat->isVersioned();
 }
 
 bool SvnItem::isValid()const
@@ -354,31 +352,31 @@ bool SvnItem::isValid()const
 
 bool SvnItem::isRealVersioned()const
 {
-    return p_Item->m_Stat.isRealVersioned();
+    return p_Item->m_Stat->isRealVersioned();
 }
 
 bool SvnItem::isIgnored()const
 {
-    return p_Item->m_Stat.textStatus()==svn_wc_status_ignored;
+    return p_Item->m_Stat->textStatus()==svn_wc_status_ignored;
 }
 
 bool SvnItem::isRemoteAdded()const
 {
-    return getWrapper()->isUpdated(p_Item->m_Stat.path()) &&
-            p_Item->m_Stat.validReposStatus()&&!p_Item->m_Stat.validLocalStatus();
+    return getWrapper()->isUpdated(p_Item->m_Stat->path()) &&
+            p_Item->m_Stat->validReposStatus()&&!p_Item->m_Stat->validLocalStatus();
 }
 
 QString SvnItem::infoText()const
 {
     QString info_text = "";
-    if (getWrapper()->isUpdated(p_Item->m_Stat.path())) {
-        if (p_Item->m_Stat.validReposStatus()&&!p_Item->m_Stat.validLocalStatus()) {
+    if (getWrapper()->isUpdated(p_Item->m_Stat->path())) {
+        if (p_Item->m_Stat->validReposStatus()&&!p_Item->m_Stat->validLocalStatus()) {
             info_text = i18n("Added in repository");
         } else {
             info_text = i18n("Needs update");
         }
     } else {
-    switch(p_Item->m_Stat.textStatus ()) {
+    switch(p_Item->m_Stat->textStatus ()) {
     case svn_wc_status_modified:
         info_text = i18n("Locally modified");
         break;
@@ -413,7 +411,7 @@ QString SvnItem::infoText()const
         break;
     }
     if (info_text.isEmpty()) {
-        switch (p_Item->m_Stat.propStatus ()) {
+        switch (p_Item->m_Stat->propStatus ()) {
         case svn_wc_status_modified:
             info_text = i18n("Property modified");
             break;
@@ -427,27 +425,27 @@ QString SvnItem::infoText()const
 
 QString SvnItem::cmtAuthor()const
 {
-    return p_Item->m_Stat.entry().cmtAuthor();
+    return p_Item->m_Stat->entry().cmtAuthor();
 }
 
 long int SvnItem::cmtRev()const
 {
-    return p_Item->m_Stat.entry().cmtRev();
+    return p_Item->m_Stat->entry().cmtRev();
 }
 
 bool SvnItem::isLocked()const
 {
-    return p_Item->m_Stat.entry().lockEntry().Locked();
+    return p_Item->m_Stat->entry().lockEntry().Locked();
 }
 
 QString SvnItem::lockOwner()const
 {
-    if (p_Item->m_Stat.entry().lockEntry().Locked()) {
-        return p_Item->m_Stat.entry().lockEntry().Owner();
+    if (p_Item->m_Stat->entry().lockEntry().Locked()) {
+        return p_Item->m_Stat->entry().lockEntry().Owner();
     }
-    svn::Status tmp;
-    if (getWrapper()->checkReposLockCache(fullName(),tmp)) {
-        return tmp.lockEntry().Owner();
+    svn::SharedPointer<svn::Status> tmp;
+    if (getWrapper()->checkReposLockCache(fullName(),tmp) && tmp) {
+        return tmp->lockEntry().Owner();
     }
     return "";
 }
@@ -458,11 +456,11 @@ QString SvnItem::lockOwner()const
  */
 bool SvnItem::isModified()const
 {
-    return p_Item->m_Stat.textStatus ()==svn_wc_status_modified||p_Item->m_Stat.propStatus()==svn_wc_status_modified
-            ||p_Item->m_Stat.textStatus ()==svn_wc_status_replaced;
+    return p_Item->m_Stat->textStatus ()==svn_wc_status_modified||p_Item->m_Stat->propStatus()==svn_wc_status_modified
+            ||p_Item->m_Stat->textStatus ()==svn_wc_status_replaced;
 }
 
-const svn::Status& SvnItem::stat()const
+const svn::StatusPtr& SvnItem::stat()const
 {
     return p_Item->m_Stat;
 }
@@ -473,17 +471,17 @@ const svn::Status& SvnItem::stat()const
  */
 bool SvnItem::isNormal()const
 {
-    return p_Item->m_Stat.textStatus()==svn_wc_status_normal;
+    return p_Item->m_Stat->textStatus()==svn_wc_status_normal;
 }
 
 bool SvnItem::isMissing()const
 {
-    return p_Item->m_Stat.textStatus()==svn_wc_status_missing;
+    return p_Item->m_Stat->textStatus()==svn_wc_status_missing;
 }
 
 bool SvnItem::isDeleted()const
 {
-    return p_Item->m_Stat.textStatus()==svn_wc_status_deleted;
+    return p_Item->m_Stat->textStatus()==svn_wc_status_deleted;
 }
 
 /*!
@@ -492,13 +490,13 @@ bool SvnItem::isDeleted()const
 const QString& SvnItem::getToolTipText()
 {
     if (p_Item->m_infoText.isNull()) {
-        if (isRealVersioned() && !p_Item->m_Stat.entry().url().isEmpty()) {
+        if (isRealVersioned() && !p_Item->m_Stat->entry().url().isEmpty()) {
             SvnActions*wrap = getWrapper();
             svn::Revision peg(svn_opt_revision_unspecified);
             svn::Revision rev(svn_opt_revision_unspecified);
-            if (QString::compare(p_Item->m_Stat.entry().url(),p_Item->m_Stat.path())==0) {
+            if (QString::compare(p_Item->m_Stat->entry().url(),p_Item->m_Stat->path())==0) {
                 /* remote */
-                rev = p_Item->m_Stat.entry().revision();
+                rev = p_Item->m_Stat->entry().revision();
                 peg = correctPeg();
             } else {
                 /* local */
