@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 by Rajko Albrecht                                  *
+ *   Copyright (C) 2005-2007 by Rajko Albrecht                             *
  *   ral@alwins-world.de                                                   *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,7 +22,7 @@
 #define __SVN_ITEM_H
 
 #include "src/svnqt/smart_pointer.hpp"
-#include "src/svnqt/status.hpp"
+#include "src/svnqt/svnqttypes.hpp"
 #include <kmimetype.h>
 #include <qstring.h>
 #include <qdatetime.h>
@@ -44,7 +44,7 @@ class SvnItem
 {
 public:
     SvnItem();
-    SvnItem(const svn::Status&);
+    SvnItem(const svn::StatusPtr&);
     virtual ~SvnItem();
 
     virtual const QString&fullName()const;
@@ -65,6 +65,7 @@ public:
     virtual bool isLocked()const;
     virtual QString lockOwner()const;
     virtual QString getParentDir()const=0;
+    virtual SvnItem* getParentItem()const=0;
     virtual const svn::Revision&correctPeg()const=0;
     virtual void refreshStatus(bool childs=false,QPtrList<SvnItem> *exclude = 0,bool depsonly=false)=0;
 
@@ -72,10 +73,12 @@ public:
     QPixmap getPixmap(const QPixmap&,int size,bool overlay=true);
 
     virtual FileListViewItem*fItem(){return 0;}
-    virtual void setStat(const svn::Status&);
-    virtual const svn::Status& stat()const;
+    virtual void setStat(const svn::StatusPtr&);
+    virtual const svn::StatusPtr& stat()const;
     virtual bool isModified()const;
     bool isNormal()const;
+    bool isMissing()const;
+    bool isDeleted()const;
     const QString& getToolTipText();
     KFileItem*fileItem();
 
