@@ -1,7 +1,7 @@
-/* 
+/*
  * Port for usage with qt-framework and development for kdesvn
  * (C) 2005-2007 by Rajko Albrecht
- * http://www.alwins-world.de/wiki/programs/kdesvn
+ * http://kdesvn.alwins-world.de
  */
 /*
  * ====================================================================
@@ -38,6 +38,8 @@
 
 #include <svn_cmdline.h>
 
+#include <qstringlist.h>
+
 namespace svn
 {
   //! this namespace contains only internal stuff not for public use
@@ -111,6 +113,18 @@ namespace svn
             url2Revision(revstring,start,end);
         }
   }
+
+  const apr_array_header_t * Client_impl::list2array(const QStringList&what,const Pool & pool)const
+  {
+      apr_array_header_t *apr_targets = apr_array_make (pool,what.size(),sizeof (const char *));
+      QStringList::const_iterator it;
+      for (it = what.begin();it!=what.end();++it) {
+          QByteArray s = (*it).TOUTF8();
+          char * t2 = apr_pstrndup (pool,s,s.size());
+          (*((const char **) apr_array_push (apr_targets))) = t2;
+      }
+      return apr_targets;
+  }
 }
 
 /* -----------------------------------------------------------------
