@@ -1,7 +1,7 @@
-/* 
+/*
  * Port for usage with qt-framework and development for kdesvn
  * (C) 2005-2007 by Rajko Albrecht
- * http://www.alwins-world.de/wiki/programs/kdesvn
+ * http://kdesvn.alwins-world.de
  */
 /*
  * ====================================================================
@@ -43,6 +43,9 @@
 #if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1310
 #pragma warning (disable: 4290)
 #endif
+
+class QStringList;
+
 namespace svn
 {
   namespace stream {
@@ -115,7 +118,7 @@ namespace svn
      * @param revision list specific revision when browsing remote, on working copies parameter will ignored
      * @return a Status with Statis.isVersioned = FALSE
      */
-    virtual Status
+    virtual StatusPtr
     singleStatus (const Path& path,bool update=false,const Revision revision = svn::Revision::HEAD) throw (ClientException);
 
   /**
@@ -261,15 +264,14 @@ namespace svn
     /**
      * Commits changes to the repository. This usually requires
      * authentication, see Auth.
-     * @return Returns a long representing the revision. It returns a
-     *         -1 if the revision number is invalid.
+     * @return Returns revision transferred or svn::Revision::UNDEFINED if the revision number is invalid.
      * @param targets files to commit.
      * @param message log message.
      * @param recurse whether the operation should be done recursively.
      * @param keep_locks if false unlock items in paths
      * @exception ClientException
      */
-    virtual svn_revnum_t
+    virtual svn::Revision
     commit (const Targets & targets,
             const QString& message,
             bool recurse,bool keep_locks=true) throw (ClientException);
@@ -444,7 +446,7 @@ namespace svn
      * @param limit (ignored when subversion 1.1 API)
      * @return a vector with log entries
      */
-    virtual LogEntries *
+    virtual LogEntriesPtr
     log (const Path& path, const Revision & revisionStart,
          const Revision & revisionEnd,
          bool discoverChangedPaths=false,
@@ -473,7 +475,7 @@ namespace svn
          bool discoverChangedPaths=false,
          bool strictNodeHistory=true,int limit = 0) throw (ClientException);
 
-    /**
+   /**
      * Produce diff output which describes the delta between
      * @a path/@a revision1 and @a path/@a revision2. @a path
      * can be either a working-copy path or a URL.
@@ -490,17 +492,30 @@ namespace svn
      * @param recurse whether the operation should be done recursively.
      * @param ignoreAncestry whether the files will be checked for
      * relatedness.
-     * @param noDiffDeleted if true, no diff output will be generated
-     * on deleted files.
+     * @param noDiffDeleted if true, no diff output will be generated on deleted files.
      * @param ignore_contenttype if true generate diff even the items are marked as binaries
+     * @param extra extra options for diff ("-b", "-w","--ignore-eol-style")
      * @return delta between the files
      * @exception ClientException
+    */
+    virtual QByteArray
+            diff (const Path & tmpPath, const Path & path,
+                const Revision & revision1, const Revision & revision2,
+                const bool recurse, const bool ignoreAncestry,
+                const bool noDiffDeleted,const bool ignore_contenttype,
+                const QStringList&extra)
+            throw (ClientException);
+
+    /**
+     * Same as other diff but extra options always set to empty list.
      */
     virtual QByteArray
-    diff (const Path & tmpPath, const Path & path,
-          const Revision & revision1, const Revision & revision2,
-          const bool recurse, const bool ignoreAncestry,
-          const bool noDiffDeleted,const bool ignore_contenttype) throw (ClientException);
+            diff (const Path & tmpPath, const Path & path,
+                const Revision & revision1, const Revision & revision2,
+                const bool recurse, const bool ignoreAncestry,
+                const bool noDiffDeleted,const bool ignore_contenttype)
+            throw (ClientException);
+
     /**
      * Produce diff output which describes the delta between
      * @a path1/@a revision1 and @a path2/@a revision2. @a path2
@@ -521,14 +536,27 @@ namespace svn
      * relatedness.
      * @param noDiffDeleted if true, no diff output will be generated on deleted files.
      * @param ignore_contenttype if true generate diff even the items are marked as binaries
+     * @param extra extra options for diff ("-b", "-w","--ignore-eol-style")
      * @return delta between the files
      * @exception ClientException
      */
     virtual QByteArray
-    diff (const Path & tmpPath, const Path & path1,const Path & path2,
-          const Revision & revision1, const Revision & revision2,
-          const bool recurse, const bool ignoreAncestry,
-          const bool noDiffDeleted,const bool ignore_contenttype) throw (ClientException);
+            diff (const Path & tmpPath, const Path & path1,const Path & path2,
+                const Revision & revision1, const Revision & revision2,
+                const bool recurse, const bool ignoreAncestry,
+                const bool noDiffDeleted,const bool ignore_contenttype,
+                const QStringList&extra)
+            throw (ClientException);
+
+    /**
+     * Same as other diff but extra options always set to empty list.
+     */
+    virtual QByteArray
+            diff (const Path & tmpPath, const Path & path1,const Path & path2,
+                const Revision & revision1, const Revision & revision2,
+                const bool recurse, const bool ignoreAncestry,
+                const bool noDiffDeleted,const bool ignore_contenttype)
+            throw (ClientException);
 
     /**
      * lists entries in @a pathOrUrl no matter whether local or
@@ -558,7 +586,7 @@ namespace svn
      * @param recurse
      * @return PropertiesList
      */
-    virtual PathPropertiesMapList
+    virtual PathPropertiesMapListPtr
     proplist(const Path &path,
              const Revision &revision,
              const Revision &peg,
@@ -738,6 +766,8 @@ namespace svn
                 const Revision & revision,
                 const Revision & peg_revision,
                 svn::stream::SvnStream&);
+
+    const apr_array_header_t * list2array(const QStringList&,const Pool &)const;
   };
 
 }
