@@ -1,3 +1,8 @@
+/*
+ * Port for usage with qt-framework and development for kdesvn
+ * (C) 2005-2007 by Rajko Albrecht
+ * http://kdesvn.alwins-world.de
+ */
 /*
  * ====================================================================
  * Copyright (c) 2002-2005 The RapidSvn Group.  All rights reserved.
@@ -168,7 +173,7 @@ namespace svn
     return resulting;
   }
 
-  svn_revnum_t
+  svn::Revision
   Client_impl::commit (const Targets & targets, const QString& message,
                   bool recurse,bool keep_locks) throw (ClientException)
   {
@@ -183,7 +188,9 @@ namespace svn
 #endif
 
     svn_error_t * error =
-#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
+#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 5)
+      svn_client_commit4
+#elif (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
       svn_client_commit3
 #else
       svn_client_commit2
@@ -199,9 +206,9 @@ namespace svn
       throw ClientException (error);
 
     if (commit_info && SVN_IS_VALID_REVNUM (commit_info->revision))
-      return commit_info->revision;
+      return (commit_info->revision);
 
-    return -1;
+    return svn::Revision::UNDEFINED;
   }
 
   void
@@ -244,7 +251,9 @@ namespace svn
     svn_client_commit_info_t *commit_info = NULL;
 #endif
     svn_error_t * error =
-#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
+#if (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 4)
+    svn_client_move4
+#elif (SVN_VER_MAJOR >= 1) && (SVN_VER_MINOR >= 3)
     svn_client_move3
 #else
     svn_client_move2
@@ -389,20 +398,45 @@ namespace svn
                   const QString& url,
                   const QString& message,
                   bool recurse) throw (ClientException)
+    {
+        import(path,url,message,recurse,false);
+    }
+
+  void
+  Client_impl::import (const Path & path,
+                  const QString& url,
+                  const QString& message,
+                  bool recurse,
+                  bool no_ignore) throw (ClientException)
+
   {
+#if (SVN_VER_MAJOR == 1) && (SVN_VER_MINOR < 3)
+      Q_UNUSED(no_ignore);
+      svn_client_commit_info_t *commit_info = NULL;
+#else
+      svn_commit_info_t *commit_info = NULL;
+#endif
     Pool pool;
-    svn_client_commit_info_t *commit_info = NULL;
 
     m_context->setLogMessage (message);
 
     svn_error_t * error =
-      svn_client_import (&commit_info,
-                         path.cstr (),
-                         url.TOUTF8(),
-                         !recurse,
-                         *m_context,
-                         pool);
-
+#if (SVN_VER_MAJOR == 1) && (SVN_VER_MINOR < 3)
+        svn_client_import (&commit_info,
+                        path.cstr (),
+                        url.TOUTF8(),
+                        !recurse,
+                        *m_context,
+                        pool);
+#else
+        svn_client_import2(&commit_info,
+                        path.cstr (),
+                        url.TOUTF8(),
+                        !recurse,
+                        no_ignore,
+                        *m_context,
+                        pool);
+#endif
     /* important! otherwise next op on repository uses that logmessage again! */
     m_context->setLogMessage(QString::null);
 
