@@ -1,3 +1,8 @@
+/*
+ * Port for usage with qt-framework and development for kdesvn
+ * (C) 2005-2007 by Rajko Albrecht
+ * http://kdesvn.alwins-world.de
+ */
 /*
  * ====================================================================
  * Copyright (c) 2002-2005 The RapidSvn Group.  All rights reserved.
@@ -240,24 +245,24 @@ namespace svn
       status = (svn_wc_status2_t *) item->value;
 
       filePath = (const char *) item->key;
-      entries.push_back (Status(filePath, status));
+      entries.push_back (StatusPtr(new Status(filePath, status)));
     }
     return entries;
   }
 
-  static Status
-  dirEntryToStatus (const Path& path, const DirEntry & dirEntry)
+  static StatusPtr
+  dirEntryToStatus (const Path& path, DirEntryPtr dirEntry)
   {
     QString url = path.path();
     url += QString::FROMUTF8("/");
-    url += dirEntry.name();
-    return Status (url, dirEntry);
+    url += dirEntry->name();
+    return StatusPtr(new Status (url, dirEntry));
   }
 
-  static Status
+  static StatusPtr
   infoEntryToStatus(const Path&,const InfoEntry&infoEntry)
   {
-    return Status(infoEntry.url(),infoEntry);
+    return StatusPtr(new Status(infoEntry.url(),infoEntry));
   }
 
   static StatusEntries
@@ -280,10 +285,11 @@ namespace svn
 
     for (it = dirEntries.begin (); it != dirEntries.end (); it++)
     {
-      const DirEntry & dirEntry = *it;
-      entries.push_back(dirEntryToStatus (path, dirEntry));
+        DirEntryPtr dirEntry = *it;
+        if (dirEntry->name().isEmpty())
+            continue;
+        entries.push_back(dirEntryToStatus (path, dirEntry));
     }
-
     return entries;
   }
 
@@ -299,14 +305,14 @@ namespace svn
   {
     if (Url::isValid (path.path())) {
         return remoteStatus (this, path, descend, get_all, update,
-                           no_ignore,revision,m_context,detailed_remote);
+                            no_ignore,revision,m_context,detailed_remote);
     } else {
-      return localStatus (path, descend, get_all, update,
-                          no_ignore, hide_externals, m_context);
+        return localStatus (path, descend, get_all, update,
+                            no_ignore, hide_externals, m_context);
     }
   }
 
-  static Status
+  static StatusPtr
   localSingleStatus (const Path& path, Context * context,bool update=false)
   {
     svn_error_t *error;
@@ -350,20 +356,20 @@ namespace svn
     status = (svn_wc_status2_t *) item->value;
     filePath = (const char *) item->key;
 
-    return Status (filePath, status);
+    return StatusPtr(new Status (filePath, status));
   };
 
-  static Status
+  static StatusPtr
   remoteSingleStatus (Client * client, const Path& path,const Revision revision, Context * )
   {
     InfoEntries infoEntries = client->info(path,false,revision,Revision(Revision::UNDEFINED));
     if (infoEntries.size () == 0)
-      return Status ();
+      return StatusPtr(new Status());
     else
       return infoEntryToStatus (path, infoEntries [0]);
   }
 
-  Status
+  StatusPtr
   Client_impl::singleStatus (const Path& path,bool update,const Revision revision) throw (ClientException)
   {
     if (Url::isValid (path.path()))
@@ -405,14 +411,14 @@ namespace svn
     return true;
   }
 
-  LogEntries *
+  LogEntriesPtr
   Client_impl::log (const Path& path, const Revision & revisionStart,
                const Revision & revisionEnd, bool discoverChangedPaths,
                bool strictNodeHistory,int limit) throw (ClientException)
   {
     Targets target(path);
     Pool pool;
-    LogEntries * entries = new LogEntries ();
+    LogEntriesPtr entries = LogEntriesPtr(new LogEntries ());
     sBaton l_baton;
     l_baton.m_context=m_context;
     l_baton.m_data = entries;
@@ -433,7 +439,6 @@ namespace svn
 
     if (error != NULL)
     {
-      delete entries;
       throw ClientException (error);
     }
 
