@@ -1,3 +1,8 @@
+/* 
+ * Port for usage with qt-framework and development for kdesvn
+ * (C) 2005-2007 by Rajko Albrecht
+ * http://kdesvn.alwins-world.de
+ */
 /*
  * ====================================================================
  * Copyright (c) 2002-2005 The RapidSvn Group.  All rights reserved.
@@ -26,6 +31,11 @@
 #ifndef _SVNCPP_WC_HPP_
 #define _SVNCPP_WC_HPP_
 
+// Ignore MSVC 7 & 2005 compiler warning: C++ exception specification
+#if defined (_MSC_VER) && _MSC_VER > 1200 && _MSC_VER <= 1410
+#pragma warning (disable: 4290)
+#endif
+
 // svncpp
 #include "svnqt/exception.hpp"
 #include "svnqt/revision.hpp"
